@@ -14,7 +14,7 @@ use Map::Tube::GraphViz::Utils qw(node_color);
 use Scalar::Util qw(blessed);
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -26,7 +26,7 @@ sub new {
 	# Edge callback.
 	$self->{'callback_edge'} = sub {
 		my ($self, $from, $to) = @_;
-		$self->{'_g'}->add_edge(
+		$self->{'g'}->add_edge(
 			'from' => $from,
 			'to' => $to,
 		);
@@ -42,6 +42,9 @@ sub new {
 	# Name of map.
 	$self->{'name'} = undef;
 
+	# GraphViz2 object.
+	$self->{'g'} = undef;
+
 	# Output.
 	$self->{'output'} = 'png';
 
@@ -61,26 +64,43 @@ sub new {
 		err "Parameter 'tube' must be 'Map::Tube' object.";
 	}
 
-	# GraphViz object.
-	my $name = $self->{'name'} || $self->{'tube'}->name;
-	$self->{'_g'} = GraphViz2->new(
-		'global' => {
-			'directed' => 0,
-		},
-		$name ? (
-			'graph' => {
-				'label' => $name,
-				'labelloc' => 'top',
+	# GraphViz2 object.
+	if (defined $self->{'g'}) {
+		if (defined $self->{'name'}) {
+			err "Parameter 'name' cannot be used with ".
+				"'g' parameter.";
+		}
+
+		# Check GraphViz2 object.
+		if (! blessed($self->{'g'})
+			|| ! $self->{'g'}->isa('GraphViz2')) {
+
+			err "Parameter 'g' must be 'GraphViz2' object.";
+		}
+	} else {
+		my $name = $self->{'name'};
+		if (! defined $name) {
+			$name = $self->{'tube'}->name;
+		}
+		$self->{'g'} = GraphViz2->new(
+			'global' => {
+				'directed' => 0,
 			},
-		) : (),
-	);
+			$name ? (
+				'graph' => {
+					'label' => $name,
+					'labelloc' => 'top',
+				},
+			) : (),
+		);
+	}
 
 	# Check output format.
 	if (! defined $self->{'output'}) {
 		err "Parameter 'output' is required.";
 	}
 	if (none { $self->{'output'} eq $_ }
-		keys %{$self->{'_g'}->valid_attributes->{'output_format'}}) {
+		keys %{$self->{'g'}->valid_attributes->{'output_format'}}) {
 
 		err "Unsupported 'output' parameter '$self->{'output'}'.";
 	}
@@ -111,7 +131,7 @@ sub graph {
 		}
 	}
 	eval {
-		$self->{'_g'}->run(
+		$self->{'g'}->run(
 			'driver' => $self->{'driver'},
 			'format' => $self->{'output'},
 			'output_file' => $output_file,
@@ -120,7 +140,7 @@ sub graph {
 	if ($EVAL_ERROR) {
 		err 'Cannot create GraphViz output.',
 			'Error', $EVAL_ERROR,
-			'Dot input', $self->{'_g'}->dot_input;
+			'Dot input', $self->{'g'}->dot_input;
 	}
 	return;
 }
@@ -157,7 +177,7 @@ Map::Tube::GraphViz - GraphViz output for Map::Tube.
  Default value is this:
  sub { 
          my ($self, $from, $to) = @_;
-         $self->{'_g'}->add_edge(
+         $self->{'g'}->add_edge(
          	'from' => $from,
          	'to' => $to,
          );
@@ -174,9 +194,27 @@ Map::Tube::GraphViz - GraphViz output for Map::Tube.
  GraphViz2 driver.
  Default value is 'neato'.
 
+=item * C<g>
+
+ GraphViz2 object.
+ Parameters 'g' and 'name' cannot combine.
+ Default value is this:
+ GraphViz2->new(
+ 	'global' => {
+ 		'directed' => 0,
+ 	},
+ 	$name ? (
+ 		'graph' => {
+ 			'label' => $name,
+ 			'labelloc' => 'top',
+ 		},
+ 	) : (),
+ );
+
 =item * C<name>
 
  Name of map.
+ Parameters 'g' and 'name' cannot combine.
  Default value is Map::Tube->name or undef.
 
 =item * C<output>
@@ -249,7 +287,6 @@ Map::Tube::GraphViz - GraphViz output for Map::Tube.
  
  # GraphViz object.
  my $g = Map::Tube::GraphViz->new(
-         'driver' => 'neato',
          'tube' => $tube,
  );
  
@@ -263,7 +300,15 @@ Map::Tube::GraphViz - GraphViz output for Map::Tube.
  # Usage: /tmp/SZXfa2g154 metro
 
  # Output with 'Berlin' argument like:
- # -rw-r--r-- 1 skim skim 1503518 Dec 17 01:10 Berlin.png
+ # -rw-r--r-- 1 skim skim 1503067 Jan 27 07:24 Berlin.png
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-GraphViz/master/images/ex1.png">
+  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-GraphViz/master/images/ex1.png" alt="Berlin" width="300px" height="300px" />
+</a>
+
+=end html
 
 =head1 EXAMPLE2
 
@@ -302,7 +347,6 @@ Map::Tube::GraphViz - GraphViz output for Map::Tube.
  # GraphViz object.
  my $g = Map::Tube::GraphViz->new(
          'callback_node' => \&node_color_without_label,
-         'driver' => 'neato',
          'tube' => $tube,
  );
  
@@ -316,7 +360,86 @@ Map::Tube::GraphViz - GraphViz output for Map::Tube.
  # Usage: /tmp/SZXfa2g154 metro
 
  # Output with 'Berlin' argument like:
- # -rw-r--r-- 1 skim skim 1503518 Dec 17 01:10 Berlin.png
+ # -rw-r--r-- 1 skim skim 885928 Jan 27 07:43 Berlin.png
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-GraphViz/master/images/ex2.png">
+  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-GraphViz/master/images/ex2.png" alt="Berlin" width="300px" height="300px" />
+</a>
+
+=end html
+
+=head1 EXAMPLE3
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use English;
+ use Error::Pure qw(err);
+ use GraphViz2;
+ use Map::Tube::GraphViz;
+ use Map::Tube::GraphViz::Utils qw(node_color_without_label);
+
+ # Arguments.
+ if (@ARGV < 1) {
+         print STDERR "Usage: $0 metro\n";
+         exit 1;
+ }
+ my $metro = $ARGV[0];
+ 
+ # Object.
+ my $class = 'Map::Tube::'.$metro;
+ eval "require $class;";
+ if ($EVAL_ERROR) {
+         err "Cannot load '$class' class.",
+                 'Error', $EVAL_ERROR;
+ }
+ 
+ # Metro object.
+ my $tube = eval "$class->new";
+ if ($EVAL_ERROR) {
+         err "Cannot create object for '$class' class.",
+                 'Error', $EVAL_ERROR;
+ }
+ 
+ # GraphViz object.
+ my $g = Map::Tube::GraphViz->new(
+         'callback_node' => \&node_color_without_label,
+         'g' => GraphViz2->new(
+                 'global' => {
+                         'directed' => 0,
+                 },
+                 'graph' => {
+                         'label' => $metro,
+                         'labelloc' => 'top',
+                         'overlap' => 0,
+                 },
+         ),
+         'tube' => $tube,
+ );
+ 
+ # Get graph to file.
+ $g->graph($metro.'.png');
+
+ # Print file.
+ system "ls -l $metro.png";
+
+ # Output without arguments like:
+ # Usage: /tmp/SZXfa2g154 metro
+
+ # Output with 'Berlin' argument like:
+ # -rw-r--r-- 1 skim skim 1212857 Jan 27 07:51 Berlin.png
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-GraphViz/master/images/ex3.png">
+  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-GraphViz/master/images/ex3.png" alt="Berlin" width="300px" height="300px" />
+</a>
+
+=end html
 
 =head1 DEPENDENCIES
 
@@ -364,6 +487,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
