@@ -18,13 +18,13 @@ Readonly::Array our @COLORS => qw(red green yellow cyan magenta blue grey
 );
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Create GraphViz color node.
 sub node_color {
 	my ($obj, $node) = @_;
 	my %params = _node_color_params($obj, $node);
-	$obj->{'_g'}->add_node(
+	$obj->{'g'}->add_node(
 		'label' => $node->name,
 		'name' => $node->id,
 		%params,
@@ -36,7 +36,7 @@ sub node_color {
 sub node_color_without_label {
 	my ($obj, $node) = @_;
 	my %params = _node_color_params($obj, $node);
-	$obj->{'_g'}->add_node(
+	$obj->{'g'}->add_node(
 		'label' => '',
 		'name' => $node->id,
 		%params,
@@ -163,6 +163,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
