@@ -33,7 +33,6 @@ if ($EVAL_ERROR) {
 
 # GraphViz object.
 my $g = Map::Tube::GraphViz->new(
-        'driver' => 'neato',
         'tube' => $tube,
 );
 
@@ -47,4 +46,4 @@ system "ls -l $metro.png";
 # Usage: /tmp/SZXfa2g154 metro
 
 # Output with 'Berlin' argument like:
-# -rw-r--r-- 1 skim skim 1503518 Dec 17 01:10 Berlin.png
\ No newline at end of file
+# -rw-r--r-- 1 skim skim 1503067 Jan 27 07:24 Berlin.png
\ No newline at end of file
